@@ -283,6 +283,8 @@ list_item_to_sv ( hexchat_list *list, const char *const *fields )
 	return sv_2mortal (newRV_noinc ((SV *) hash));
 }
 
+#define WORD_ARRAY_LEN 32
+
 static AV *
 array2av (char *array[])
 {
@@ -293,7 +295,7 @@ array2av (char *array[])
 
 	for (
 		count = 1;
-		count < 32 && array[count] != NULL && array[count][0] != 0;
+		count < WORD_ARRAY_LEN && array[count] != NULL && array[count][0] != 0;
 		count++
 	) {
 		temp = newSVpv (array[count], 0);
@@ -1554,9 +1556,6 @@ perl_command_eval (char *word[], char *word_eol[], void *userdata)
 	return HEXCHAT_EAT_HEXCHAT;
 }
 
-#ifdef __CYGWIN__
-__declspec(dllexport)
-#endif
 void
 hexchat_plugin_get_info (char **name, char **desc, char **version,
 							  void **reserved)
@@ -1573,9 +1572,6 @@ hexchat_plugin_get_info (char **name, char **desc, char **version,
 
 static int initialized = 0;
 
-#ifdef __CYGWIN__
-__declspec(dllexport)
-#endif
 int
 hexchat_plugin_init (hexchat_plugin * plugin_handle, char **plugin_name,
 						 char **plugin_desc, char **plugin_version, char *arg)
@@ -1615,9 +1611,6 @@ hexchat_plugin_init (hexchat_plugin * plugin_handle, char **plugin_name,
 	return 1;
 }
 
-#ifdef __CYGWIN__
-__declspec(dllexport)
-#endif
 int
 hexchat_plugin_deinit (hexchat_plugin * plugin_handle)
 {
